@@ -1,4 +1,4 @@
-from bionumpy.gfa import GfaPathBuffer
+from bionumpy.io.gfa import GfaPathBuffer
 import pytest
 import bionumpy as bnp
 
