@@ -2,14 +2,15 @@ import pytest
 import bionumpy as bnp
 import numpy as np
 
+import bionumpy.encoded_array
 from bionumpy import as_encoded_array
-from bionumpy.wildcard_index import WildCardIndex, WildCardLookup
-from bionumpy.testing import assert_encoded_raggedarray_equal
+from bionumpy.sequence.indexing import WildCardIndex, WildCardLookup
+from bionumpy.util.testing import assert_encoded_raggedarray_equal
 
 
 @pytest.fixture
 def sequences():
-    return bnp.as_encoded_array(["ACGTACG", "CGTAGT"], bnp.DNAEncoding)
+    return bionumpy.encoded_array.as_encoded_array(["ACGTACG", "CGTAGT"], bnp.DNAEncoding)
 
 
 def test_wildcard_index(sequences):
